@@ -3,9 +3,8 @@ import time
 import torch
 import torch.nn as nn
 
-from .generator import Generator
-
-from .preprocessing import Preprocessing
+from generator import Generator
+from preprocessing import Preprocessing
 
 
 class GRUGenerator(Generator):
@@ -119,7 +118,7 @@ class GRUGenerator(Generator):
         """
         criterion, optimizer = self.get_loss_and_train_op(0.01)
 
-        iteration = 0
+        batch_count = 0
         total_iterations = (len(self.db) // self.batchSize) * self.epochs
 
         for e in range(self.epochs):        
@@ -136,7 +135,7 @@ class GRUGenerator(Generator):
                 start_time = time.time()
                 src_lengths, _ ,src_batch,trg_batch = self.get_src_trg(batch)
 
-                iteration += 1
+                batch_count += 1
 
                 self.train()
                 optimizer.zero_grad()
@@ -166,13 +165,13 @@ class GRUGenerator(Generator):
                 batch_time = time.time() - start_time
                 batch_times.append(batch_time)
 
-                if iteration % 10 == 0:
+                if batch_count % 10 == 0:
                     mean_time = sum(batch_times)/len(batch_times)
-                    remaining_iters = total_iterations - iteration       
-                    remaining_seconds = remaining_iters * mean_time 
+                    remaining_batches = batches_len - batch_count       
+                    remaining_seconds = remaining_batches * mean_time 
                     remaining_time = time.strftime("%H:%M:%S",
                         time.gmtime(remaining_seconds))
-                    progress = "{:.2%}".format(iteration/total_iterations)
+                    progress = "{:.2%}".format(batch_count/batches_len)
                     print('Epoch: {}/{}'.format(e+1, self.epochs),
                           'Progress:', progress,
                           'Loss: {}'.format(loss_value),
@@ -191,4 +190,4 @@ class GRUGenerator(Generator):
 
             They are optional while calling this method. The values passed while creating the generator object will be used.
         """
-        return super(GRUGenerator, self).generateDocument('GRU', predIter, selection, k, prob)
+        return super(GRUGenerator, self).generateDocument('GRU', predIter, selection, k, prob)
\ No newline at end of file
